@@ -566,7 +566,7 @@ QByteArray ContactsPrivate::contactToXML(const KGAPI::Object* object)
     if (!contact->familyName().isEmpty())
         output.append("<gd:familyName>").append(contact->familyName().toUtf8()).append("</gd:familyName>");
     if (!contact->assembledName().isEmpty())
-        output.append("<gd:fullName>").append(contact->assembledName().toUtf8()).append("</gd:fullName>");
+        output.append("<gd:fullName>").append(contact->formattedName().toUtf8()).append("</gd:fullName>");
     if (!contact->additionalName().isEmpty())
         output.append("<gd:additionalName>").append(contact->additionalName().toUtf8()).append("</gd:additionalName>");
     if (!contact->prefix().isEmpty())
@@ -692,9 +692,10 @@ QByteArray ContactsPrivate::contactToXML(const KGAPI::Object* object)
     }
 
     /* Birthday */
-    if (!contact->birthday().isNull() && contact->birthday().isValid()) {
-        QString birthday = contact->birthday().toString("yyyy-MM-dd");
-        output.append("<gContact:birthday when='").append(birthday.toUtf8()).append("'/>");
+    QDate birthday = contact->birthday().date();
+    if (birthday.isValid()) {
+        QString birthdayStr = birthday.toString("yyyy-MM-dd");
+        output.append("<gContact:birthday when='").append(birthdayStr.toUtf8()).append("'/>");
     }
 
     QStringList groups = contact->custom("GCALENDAR", "groupMembershipInfo").split(',');
